.. highlight:: shell

============
Installation
============

At the command line::

    $ pip install dicompylercore

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv dicompylercore
    $ pip install dicompylercore
